//------------------------------------------------------------------------
//
// OpenDCC - DCC Sniffer
//
// Copyright (c) 2008 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      led_control.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-03-02 V0.1 kw started
//
//------------------------------------------------------------------------
//
// purpose:   DCC sniffer
//            here: timing and status engine for LEDs
//
// content:   1. Interface
//               calls for on, off, blinking, flashing, ...
//            2  runtime-part
//               must be called every time_tick
//
//------------------------------------------------------------------------

//=============================================================================
// 1. Definitions
//=============================================================================
//
//
// #define LED_PROG     0     // program   - yellow
// #define LED_RAILCOM  1     // railcom   - yellow
// #define LED_ACC      2     // accessory - green
// #define LED_LOCO     3     // loco      - green
// #define LED_GO       4     // sniffing  - blue
// #define LED_ON       5     // on        - green


#define OFF     0
#define ON      1

#define LED_INPORT      PINA
#define LED_OUTPORT     PORTA

//=============================================================================
// 2. Calls
//=============================================================================
//
// use one of the above numbers for myled

extern void led_on(unsigned char myled);

extern void led_half(unsigned char myled);          // make 33% duty cycle

extern void led_highlight(unsigned char myled);  // add a short pulse highlighted to 33%

extern void led_half_pulse(unsigned char myled);      // make a short pulse (33%);

extern void led_off(unsigned char myled);

extern void led_pulse(unsigned char myled);        // make a single pulse

extern void led_fast_pulse(unsigned char myled);

extern void led_double_pulse(unsigned char myled); // make a double pulse

extern void led_blinking(unsigned char myled);     // slow blinking

extern void led_fast_flash(unsigned char myled, unsigned char count); // make a series of flashes, then a longer pause

extern void led_XoooXooo(unsigned char myled);

extern void led_oXXXoXXX(unsigned char myled);

extern void led_XoooooXooooo(unsigned char myled);

extern void led_oXXXXXoXXXXX(unsigned char myled);

extern void init_led(void);

extern void run_led(void);             // to be called in main loop every tick

