//----------------------------------------------------------------
//
// OpenDCC
//
// Copyright (c) 2006 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//-----------------------------------------------------------------
//
// file:      rs485.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2008-07-11 V0.1 started
//
//-----------------------------------------------------------------
//
// purpose:   lowcost central station for dcc
// content:   routines for Xpressnet master (RS485)
//
//-----------------------------------------------------------------


#ifndef __RS485_H__
#define __RS485_H__


//=============================================================================
// Upstream Interface
//----------------------------------------------------------------------------
//
void X_init_rs485(void);

void set_XP_to_receive(void);
void set_XP_to_transmit(void);


void XP_send_call_byte (const unsigned char c);  // sends one byte directly, bit 8 = 1;
bool XP_send_byte (const unsigned char c);       // sends one byte with isr and fifo, bit 8 = 0
bool XP_is_all_sent(void);                       // true if fifo is empty and all data are sent
bool XP_tx_ready (void);                         // true if byte can be sent

unsigned int XP_rx_read (void);                  // reads one 'byte'; int since we have 9 bits!
bool XP_rx_ready (void);                         // true if one byte can be read



// debug only:

#define X_RxBuffer_Size  64              // mind. 16
extern unsigned int X_RxBuffer[X_RxBuffer_Size];

#define X_TxBuffer_Size  64
extern unsigned char X_TxBuffer[X_TxBuffer_Size];

extern unsigned char X_rx_read_ptr;        // point to next read
extern unsigned char X_rx_write_ptr;       // point to next write
extern unsigned char X_rx_fill;
extern unsigned char X_tx_read_ptr;
extern unsigned char X_tx_write_ptr;
extern unsigned char X_tx_fill;


#if (DEBUG == 3)
  void X_push_to_rx(unsigned char d);
#endif


#endif  // __RS485_H__
